import{_ as m}from"./TasksView.vue_vue_type_script_setup_true_lang.1a37e008.js";import{R as f}from"./tasksController.a7296231.js";import{d as b,ea as _,f as y,o as n,Y as g,b as w,w as k,u as l,c as I,S as T,aS as v,aG as B,dd as S}from"./index.b466b20d.js";import"./gateway.973a0055.js";import{a as j,B as x}from"./build.233f0a6a.js";import{a as C}from"./project.eb1f21da.js";import"./tables.1fa225bd.js";import{a as D}from"./asyncComputed.4467697c.js";import"./metadata.0f251151.js";import"./PhWebhooksLogo.vue.d1f03bcc.js";import"./ant-design.72d4f11b.js";import"./string.42378387.js";import"./dayjs.67389468.js";import"./index.a02e478f.js";import"./scripts.67bab85e.js";import"./record.fd6fbc29.js";import"./linters.a9259de0.js";import"./polling.f4d808f9.js";import"./popupNotifcation.d1201e83.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="c56caba6-a4bd-410e-a57d-75379c427007",e._sentryDebugIdIdentifier="sentry-dbid-c56caba6-a4bd-410e-a57d-75379c427007")}catch{}})();const Q=b({__name:"Tasks",setup(e){const a=_().params.projectId,c=new f(a),{result:o}=D(async()=>{const r=(await j.list(a)).find(d=>d.latest);if(!r)return null;const[p,u]=await Promise.all([x.get(r.id),C.get(a)]);return{buildSpec:p,project:u}}),i=y(()=>!o.value||!o.value.buildSpec?null:o.value.buildSpec.runtimes.map(t=>({id:t.id,stageTitle:t.title,stageType:t.type})));return(t,r)=>(n(),g(v,null,[w(l(S),null,{default:k(()=>[B("Tasks")]),_:1}),i.value?(n(),I(m,{key:0,class:"tasks",api:l(c),stages:i.value},null,8,["api","stages"])):T("",!0)],64))}});export{Q as default};
//# sourceMappingURL=Tasks.7fb4315b.js.map
