import{d as i,o as p,c as n,w as a,b as m,u as t}from"./index.b466b20d.js";import"./linters.a9259de0.js";import{W as s}from"./workspaces.ddf9dfb9.js";import{C as d}from"./ContentLayout.2ce25a75.js";import{_ as f,E as c}from"./View.vue_vue_type_script_setup_true_lang.a2ea9c9a.js";import"./asyncComputed.4467697c.js";import"./workspaceStore.dd86fabd.js";import"./url.0fe255f2.js";import"./colorHelpers.26ff5df3.js";import"./record.fd6fbc29.js";import"./gateway.973a0055.js";import"./popupNotifcation.d1201e83.js";import"./fetch.cd0b404e.js";import"./SaveButton.2ebbd765.js";import"./UnsavedChangesHandler.931e254c.js";import"./ExclamationCircleOutlined.efb4b17a.js";import"./CrudView.81ab71a6.js";import"./router.3cd4b4c4.js";import"./Badge.4eadbb30.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.47b5b5cb.js";import"./BookOutlined.948f0a8b.js";import"./PhDotsThreeVertical.vue.d63caaa3.js";import"./index.a02e478f.js";import"./index.12405f10.js";import"./polling.f4d808f9.js";import"./PhPencil.vue.bb3ccc28.js";import"./index.695b6622.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="074dfdbe-ab65-4a63-9517-cd56a088434c",o._sentryDebugIdIdentifier="sentry-dbid-074dfdbe-ab65-4a63-9517-cd56a088434c")}catch{}})();const G=i({__name:"EnvVarsEditor",setup(o){const r=new c;return(e,u)=>(p(),n(d,null,{default:a(()=>[m(f,{"env-var-repository":t(r),mode:"editor","file-opener":t(s)},null,8,["env-var-repository","file-opener"])]),_:1}))}});export{G as default};
//# sourceMappingURL=EnvVarsEditor.dc577609.js.map
