import{b as o,ee as u,eH as f}from"./index.b466b20d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="02ea7b98-18e3-4b41-8932-750a2fed1eac",e._sentryDebugIdIdentifier="sentry-dbid-02ea7b98-18e3-4b41-8932-750a2fed1eac")}catch{}})();function d(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?Object(arguments[t]):{},r=Object.keys(n);typeof Object.getOwnPropertySymbols=="function"&&(r=r.concat(Object.getOwnPropertySymbols(n).filter(function(a){return Object.getOwnPropertyDescriptor(n,a).enumerable}))),r.forEach(function(a){l(e,a,n[a])})}return e}function l(e,t,n){return t in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}var i=function(t,n){var r=d({},t,n.attrs);return o(u,d({},r,{icon:f}),null)};i.displayName="LoadingOutlined";i.inheritAttrs=!1;const s=i;export{s as L};
//# sourceMappingURL=LoadingOutlined.704d86ff.js.map
