import{b as o,ee as c,ei as u}from"./index.b466b20d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="946ac680-b563-4166-a967-386e3dc3a703",e._sentryDebugIdIdentifier="sentry-dbid-946ac680-b563-4166-a967-386e3dc3a703")}catch{}})();function a(e){for(var t=1;t<arguments.length;t++){var r=arguments[t]!=null?Object(arguments[t]):{},n=Object.keys(r);typeof Object.getOwnPropertySymbols=="function"&&(n=n.concat(Object.getOwnPropertySymbols(r).filter(function(i){return Object.getOwnPropertyDescriptor(r,i).enumerable}))),n.forEach(function(i){d(e,i,r[i])})}return e}function d(e,t,r){return t in e?Object.defineProperty(e,t,{value:r,enumerable:!0,configurable:!0,writable:!0}):e[t]=r,e}var l=function(t,r){var n=a({},t,r.attrs);return o(c,a({},n,{icon:u}),null)};l.displayName="CloseCircleOutlined";l.inheritAttrs=!1;const f=l;export{f as C};
//# sourceMappingURL=CloseCircleOutlined.4866fb11.js.map
