import"./index.b466b20d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="590db909-5b27-4a55-9c4b-40572b4e86b4",e._sentryDebugIdIdentifier="sentry-dbid-590db909-5b27-4a55-9c4b-40572b4e86b4")}catch{}})();function n(e,t){return e.toLocaleString(void 0,{hour12:!1,timeZoneName:"short",day:"2-digit",month:"2-digit",year:"numeric",hour:"2-digit",minute:"2-digit",second:"2-digit",weekday:"long",...t})}export{n as g};
//# sourceMappingURL=datetime.7c106b19.js.map
