import{P as f}from"./PlayerNavbar.8a1433cb.js";import{d as g,eo as h,ea as c,e as b,f as y,r as k,o as i,Y as v,u as n,c as w,S as L,a as C,b as I,a0 as N}from"./index.b466b20d.js";import{u as V}from"./workspaceStore.dd86fabd.js";import"./metadata.0f251151.js";import"./PhWebhooksLogo.vue.d1f03bcc.js";import"./LoadingOutlined.704d86ff.js";import"./PhSignOut.vue.682988c2.js";import"./index.647ccb31.js";import"./Avatar.1c21d807.js";import"./url.0fe255f2.js";import"./colorHelpers.26ff5df3.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="adcf4880-c0bb-403a-9c88-0299c82c510b",o._sentryDebugIdIdentifier="sentry-dbid-adcf4880-c0bb-403a-9c88-0299c82c510b")}catch{}})();const x={class:"main-container"},B={class:"content"},D=g({__name:"Main",setup(o){const e=h(),t=V(),u=c().path,a=b(null),d=async({path:s,id:r})=>{a.value=r,await e.push({path:`/${s}`}),a.value=null},l=()=>{e.push({name:"playerLogin"})},p=()=>{e.push({name:"playerLogin"})},_=y(()=>!!c().meta.hideLogin);return(s,r)=>{const m=k("RouterView");return i(),v("div",x,[n(t).state.workspace?(i(),w(f,{key:0,"current-path":n(u),"hide-login":_.value,"runner-data":n(t).state.workspace,loading:a.value,onNavigate:d,onLoginClick:p,onLogoutClick:l},null,8,["current-path","hide-login","runner-data","loading"])):L("",!0),C("section",B,[I(m)])])}}});const A=N(D,[["__scopeId","data-v-f095bece"]]);export{A as default};
//# sourceMappingURL=Main.d3d2a9df.js.map
