import{d as k,e as B,X as h,o as n,c as u,w as f,b as A,aG as I,e9 as P,ed as C,eQ as D,u as y,bT as N,eU as q,a0 as S,ea as V,S as b,a as g,Y as d,eb as v,ec as x,aS as w,q as E,t as L}from"./index.b466b20d.js";import{S as $}from"./Steps.42f41182.js";import{W as F}from"./PlayerConfigProvider.4015a478.js";import"./index.f3e3df19.js";import"./colorHelpers.26ff5df3.js";import"./index.849469be.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[t]="025f2cb3-82bc-4cc4-b2d9-49374e45a61a",o._sentryDebugIdIdentifier="sentry-dbid-025f2cb3-82bc-4cc4-b2d9-49374e45a61a")}catch{}})();const K=k({__name:"ActionButton",props:{action:{},displayName:{},disabled:{type:Boolean},loading:{type:Boolean}},emits:["click"],setup(o,{emit:t}){const c=o,l=B(null);return h(()=>{l.value&&c.action.setElement(l.value)}),(r,i)=>(n(),u(y(q),null,{default:f(()=>[A(y(N),{ref_key:"element",ref:l,class:C(["next-button",r.disabled?"disabled":""]),loading:r.loading,disabled:r.disabled,onClick:i[0]||(i[0]=p=>t("click")),onKeydown:i[1]||(i[1]=D(p=>t("click"),["enter"]))},{default:f(()=>[I(P(r.displayName),1)]),_:1},8,["loading","disabled","class"])]),_:1}))}});const M=S(K,[["__scopeId","data-v-aea27bb7"]]),O={class:"form"},z={class:"form-wrapper"},G={key:0,class:"buttons"},J=k({__name:"WidgetPreview",setup(o){const t=V(),c=B([]);function l(e){return E[e]||L[e]||null}function r(e){try{const s=JSON.parse(e);if(s.component=l(s.type),!s.component)throw new Error(`Widget ${s.type} not found`);return s.component?s:null}catch{return null}}function i(){const e=t.query.widget;return Array.isArray(e)?e.map(r).filter(Boolean):[r(e)]}function p(){return t.query.steps==="true"}function m(){const e=t.query.button;return e?Array.isArray(e)?e:[e]:[]}const _=e=>({name:e,isDefault:!1,isFocused:!1,focusOnButton:()=>{},addKeydownListener:()=>{},setElement:()=>{}});return(e,s)=>(n(),u(F,{"main-color":"#d14056",class:"preview",background:"#fbfbfb","font-family":"Inter",locale:"en"},{default:f(()=>[p()?(n(),u($,{key:0,class:"steps","steps-info":{current:1,total:3}})):b("",!0),g("div",O,[g("div",z,[(n(!0),d(w,null,v(i(),(a,W)=>(n(),d("div",{key:W,class:"widget"},[(n(),u(x(a.component),{"user-props":a.userProps,value:a.userProps.value,errors:c.value},null,8,["user-props","value","errors"]))]))),128))]),m().length?(n(),d("div",G,[(n(!0),d(w,null,v(m(),a=>(n(),u(M,{key:a,"display-name":_(a).name,action:_(a)},null,8,["display-name","action"]))),128))])):b("",!0)])]),_:1}))}});const j=S(J,[["__scopeId","data-v-0c6cef1d"]]);export{j as default};
//# sourceMappingURL=WidgetPreview.46451841.js.map
