.logo[data-v-f2a3ae27]{display:flex;align-items:center}.logo .logo-img[data-v-f2a3ae27]{height:var(--9303a762);max-width:100%}.logo span[data-v-f2a3ae27]{font-size:20px;font-weight:600;margin-left:10px}
