import{n as t,a as i}from"./string.42378387.js";import"./index.b466b20d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="b0cb0e04-066c-4f17-9566-eb20a318fde9",e._sentryDebugIdIdentifier="sentry-dbid-b0cb0e04-066c-4f17-9566-eb20a318fde9")}catch{}})();function o(e){return e.replace(/\.py$/,"").trim().length===0?{valid:!1,reason:"File name cannot be empty"}:e.length>255?{valid:!1,reason:"File name cannot be longer than 255 characters"}:e.endsWith(".py")?{valid:!0}:{valid:!1,reason:"File name must end with .py"}}function u(e){if(!o(e).valid)throw new Error("Invalid filename");const n=e.slice(0,-3);return t(n,!0,!0,!0,!0)+".py"}function f(e){return t(e,!0,!0,!0,!0)+".py"}function s(e){return e.trim().length===0?{valid:!1,reason:"Path cannot be empty"}:{valid:!0}}function c(e){if(!s(e).valid)throw new Error("Invalid path");return e.split("/").filter(Boolean).map(r=>i(r)).join("/")}export{s as a,f as b,u as c,c as n,o as v};
//# sourceMappingURL=validations.29ed61b9.js.map
