import{a0 as a,o,Y as n,$ as s,a as d,S as r}from"./index.b466b20d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="0b800943-3d8a-4ea5-80e9-ebbfc51801ba",e._sentryDebugIdIdentifier="sentry-dbid-0b800943-3d8a-4ea5-80e9-ebbfc51801ba")}catch{}})();const c={},i={class:"base-layout"},f={class:"base-middle"},u={key:0,class:"base-footer"};function _(e,t){return o(),n("div",i,[s(e.$slots,"sidebar",{},void 0,!0),d("section",f,[s(e.$slots,"navbar",{},void 0,!0),s(e.$slots,"content",{},void 0,!0),e.$slots.footer?(o(),n("section",u,[s(e.$slots,"footer",{},void 0,!0)])):r("",!0)])])}const y=a(c,[["render",_],["__scopeId","data-v-9ad5be20"]]);export{y as B};
//# sourceMappingURL=BaseLayout.8e0836b5.js.map
