import{C as n}from"./gateway.973a0055.js";import"./index.b466b20d.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="6b243e30-36f1-49ff-8fd0-0cf2c6a9caeb",t._sentryDebugIdIdentifier="sentry-dbid-6b243e30-36f1-49ff-8fd0-0cf2c6a9caeb")}catch{}})();class i{async create(e){return n.post(`organizations/${e.organizationId}/members`,{email:e.email,teams:e.teams})}async delete(e){return n.delete(`organizations/${e.organizationId}/members/${e.authorId}`)}async list(e){return n.get(`organizations/${e}/members`)}async get(e,r){return n.get(`organizations/${e}/members/${r}`)}async update(e,r,a){return n.patch(`organizations/${e}/members/${r}`,a)}}export{i as M};
//# sourceMappingURL=member.eaf720ad.js.map
