import{_ as n,C as p}from"./View.vue_vue_type_script_setup_true_lang.a2ea9c9a.js";import{d as i,ea as s,o as a,c as m,u as d}from"./index.b466b20d.js";import"./gateway.973a0055.js";import"./popupNotifcation.d1201e83.js";import"./fetch.cd0b404e.js";import"./record.fd6fbc29.js";import"./SaveButton.2ebbd765.js";import"./UnsavedChangesHandler.931e254c.js";import"./ExclamationCircleOutlined.efb4b17a.js";import"./CrudView.81ab71a6.js";import"./router.3cd4b4c4.js";import"./Badge.4eadbb30.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.47b5b5cb.js";import"./BookOutlined.948f0a8b.js";import"./url.0fe255f2.js";import"./PhDotsThreeVertical.vue.d63caaa3.js";import"./index.a02e478f.js";import"./index.12405f10.js";import"./asyncComputed.4467697c.js";import"./polling.f4d808f9.js";import"./PhPencil.vue.bb3ccc28.js";import"./index.695b6622.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="1faa81f7-de11-4ceb-ac9b-ff494d192973",o._sentryDebugIdIdentifier="sentry-dbid-1faa81f7-de11-4ceb-ac9b-ff494d192973")}catch{}})();const A=i({__name:"EnvVars",setup(o){const e=s().params.projectId,t=new p(e);return(f,c)=>(a(),m(n,{"env-var-repository":d(t),mode:"console"},null,8,["env-var-repository"]))}});export{A as default};
//# sourceMappingURL=EnvVars.d16dca46.js.map
