import{_ as l}from"./Login.vue_vue_type_script_setup_true_lang.559b91f2.js";import{d as f,eo as m,ea as b,o as g,Y as y,b as w,u as n,a0 as k}from"./index.b466b20d.js";import{u as h}from"./workspaceStore.dd86fabd.js";import"./Logo.19805c7a.js";import"./string.42378387.js";import"./CircularLoading.c0497912.js";import"./index.849469be.js";import"./index.695b6622.js";import"./url.0fe255f2.js";import"./colorHelpers.26ff5df3.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="c935296a-23ef-45a6-816d-be30bbf509bb",e._sentryDebugIdIdentifier="sentry-dbid-c935296a-23ef-45a6-816d-be30bbf509bb")}catch{}})();const v={class:"runner"},I=f({__name:"Login",setup(e){const o=m(),t=b(),r=h(),_=async()=>{const{redirect:a,...s}=t.query;if(a){await o.push({path:a,query:s,params:t.params});return}o.push({name:"playerHome",query:s})};return(a,s)=>{var c,d,p,u,i;return g(),y("div",v,[w(l,{"logo-url":(d=(c=n(r).state.workspace)==null?void 0:c.logoUrl)!=null?d:void 0,"brand-name":(p=n(r).state.workspace)==null?void 0:p.brandName,locale:(i=(u=n(r).state.workspace)==null?void 0:u.language)!=null?i:"en",onDone:_},null,8,["logo-url","brand-name","locale"])])}}});const H=k(I,[["__scopeId","data-v-ce854d6f"]]);export{H as default};
//# sourceMappingURL=Login.1914aa36.js.map
