import{L as s}from"./Logo.19805c7a.js";import{d as t,o as n,c as r,u as d}from"./index.b466b20d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="da4a5575-906e-485d-b077-ac3f2c6a4905",e._sentryDebugIdIdentifier="sentry-dbid-da4a5575-906e-485d-b077-ac3f2c6a4905")}catch{}})();const i="/assets/logo.0faadfa2.svg",u=t({__name:"AbstraLogo",props:{hideText:{type:Boolean},size:{}},setup(e){return(a,o)=>(n(),r(s,{"image-url":d(i),"brand-name":"Abstra","hide-text":a.hideText,size:a.size},null,8,["image-url","hide-text","size"]))}});export{u as _};
//# sourceMappingURL=AbstraLogo.vue_vue_type_script_setup_true_lang.dd217b89.js.map
