import{B as d}from"./BookOutlined.948f0a8b.js";import{d as c,o as s,c as f,w as o,b as l,u as n,$ as u,Y as i,aG as p,aS as b,bT as y}from"./index.b466b20d.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="08c968af-2749-4aba-901d-7cd931caf0f8",t._sentryDebugIdIdentifier="sentry-dbid-08c968af-2749-4aba-901d-7cd931caf0f8")}catch{}})();const g=c({__name:"DocsButton",props:{path:{}},setup(t){return(e,r)=>{var a;return s(),f(n(y),{class:"docs-button",href:`https://docs.abstra.io/${(a=e.path)!=null?a:""}`,target:"_blank",type:"text",size:"small"},{icon:o(()=>[l(n(d))]),default:o(()=>[e.$slots.default?u(e.$slots,"default",{key:0}):(s(),i(b,{key:1},[p("Docs")],64))]),_:3},8,["href"])}}});export{g as _};
//# sourceMappingURL=DocsButton.vue_vue_type_script_setup_true_lang.47b5b5cb.js.map
