import{d as b,eo as m,ea as p,o as l,c as f,w as d,u as n,Y as _,eb as g,b as y,a as v,e9 as w,aS as k}from"./index.b466b20d.js";import{A as I,T}from"./TabPane.83921cd6.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="17785509-89dd-403b-99d8-477bf8452172",e._sentryDebugIdIdentifier="sentry-dbid-17785509-89dd-403b-99d8-477bf8452172")}catch{}})();const B=b({__name:"TablesTabs",setup(e){const a=m(),t=p(),u=String(t.name),c=t.params.projectId,r=[{label:"Tables list",value:"tables"},{label:"Diagram view",value:"tables-diagram"},{label:"Run SQL",value:"sql"}],i=o=>{a.push({name:String(o),params:{projectId:c}})};return(o,D)=>(l(),f(n(T),{"active-key":n(u),options:r,"onUpdate:activeKey":i},{default:d(()=>[(l(),_(k,null,g(r,s=>y(n(I),{key:s.value,name:s.value},{tab:d(()=>[v("span",null,w(s.label),1)]),_:2},1032,["name"])),64))]),_:1},8,["active-key"]))}});export{B as _};
//# sourceMappingURL=TablesTabs.vue_vue_type_script_setup_true_lang.61f8e193.js.map
