import{d as n,o as s,Y as d,a,$ as r,ed as c,a0 as l}from"./index.b466b20d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="90b7b822-52c3-4734-94cc-ff6ff245d171",e._sentryDebugIdIdentifier="sentry-dbid-90b7b822-52c3-4734-94cc-ff6ff245d171")}catch{}})();const f={class:"content-layout"},_=n({__name:"ContentLayout",props:{fullWidth:{type:Boolean}},setup(e){return(t,o)=>(s(),d("div",f,[a("div",{class:c(["centered-layout",{"full-width":t.fullWidth}])},[r(t.$slots,"default",{},void 0,!0)],2)]))}});const i=l(_,[["__scopeId","data-v-6397d501"]]);export{i as C};
//# sourceMappingURL=ContentLayout.2ce25a75.js.map
