import{C as r,E as t,K as i,a as c,M as f,c as l,P as y,R as b,S as g,b as u,T as k,U as p,e as w,l as D}from"./toggleHighContrast.ed9cac97.js";import"./index.b466b20d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="d9781e82-618d-41d2-bc99-256c8adf0fce",e._sentryDebugIdIdentifier="sentry-dbid-d9781e82-618d-41d2-bc99-256c8adf0fce")}catch{}})();export{r as CancellationTokenSource,t as Emitter,i as KeyCode,c as KeyMod,f as MarkerSeverity,l as MarkerTag,y as Position,b as Range,g as Selection,u as SelectionDirection,k as Token,p as Uri,w as editor,D as languages};
//# sourceMappingURL=editor.main.cbffda9e.js.map
