import{d as a,o,Y as s,b as d,u as r,by as _,a0 as c}from"./index.b466b20d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="e6f0bf12-e8e3-43dd-9ea1-c73b33773f4a",e._sentryDebugIdIdentifier="sentry-dbid-e6f0bf12-e8e3-43dd-9ea1-c73b33773f4a")}catch{}})();const i={class:"centered"},f=a({__name:"LoadingContainer",setup(e){return(n,t)=>(o(),s("div",i,[d(r(_))]))}});const u=c(f,[["__scopeId","data-v-52e6209a"]]);export{u as L};
//# sourceMappingURL=LoadingContainer.b1338719.js.map
