import{O as r}from"./workspaceStore.dd86fabd.js";import{d as i,X as l,o as c,Y as u,b as a,w as n,u as o,aG as d,dd as f,dc as b}from"./index.b466b20d.js";import"./url.0fe255f2.js";import"./colorHelpers.26ff5df3.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="21624b51-0ff5-4c3f-8e37-ccd7b8a3432d",e._sentryDebugIdIdentifier="sentry-dbid-21624b51-0ff5-4c3f-8e37-ccd7b8a3432d")}catch{}})();const w=i({__name:"OidcLoginCallback",setup(e){return l(async()=>{await new r().loginCallback()}),(t,s)=>(c(),u("div",null,[a(o(f),null,{default:n(()=>[d("You're authenticated")]),_:1}),a(o(b),null,{default:n(()=>[d(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{w as default};
//# sourceMappingURL=OidcLoginCallback.e05f2e2e.js.map
