import{_ as f}from"./AbstraLogo.vue_vue_type_script_setup_true_lang.dd217b89.js";import{B as y}from"./BaseLayout.8e0836b5.js";import{d as l,E as m,L as b,a0 as u,a_ as v,a$ as g,o as _,Y as h,a as r,Z as s,ea as w,eo as S,X as L,c as k,w as n,b as i,u as $}from"./index.b466b20d.js";import{u as x}from"./editor.c31d43d0.js";import{b as B}from"./index.f78751e0.js";import"./Logo.19805c7a.js";import"./workspaceStore.dd86fabd.js";import"./url.0fe255f2.js";import"./colorHelpers.26ff5df3.js";import"./linters.a9259de0.js";import"./asyncComputed.4467697c.js";import"./index.647ccb31.js";import"./Avatar.1c21d807.js";import"./index.12405f10.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="ca1ca9ff-7644-40b4-88c4-fb9abb70a964",e._sentryDebugIdIdentifier="sentry-dbid-ca1ca9ff-7644-40b4-88c4-fb9abb70a964")}catch{}})();const I=l({props:{loading:{type:Boolean,default:!0},color:{type:String,default:"#ea576a"},size:{type:String,default:"10px"},radius:{type:String,default:"100%"}},setup(e){const a=m({spinnerStyle:{width:e.size,height:e.size,borderRadius:e.radius,backgroundColor:e.color}});return{...b(a)}}});const P={class:"v-spinner"};function D(e,a,o,c,d,p){return v((_(),h("div",P,[r("div",{class:"v-beat v-beat-odd",style:s(e.spinnerStyle)},null,4),r("div",{class:"v-beat v-beat-even",style:s(e.spinnerStyle)},null,4),r("div",{class:"v-beat v-beat-odd",style:s(e.spinnerStyle)},null,4)],512)),[[g,e.loading]])}const R=u(I,[["render",D],["__scopeId","data-v-06538001"]]),j={class:"content"},z=l({__name:"ProjectLogin",setup(e){const a=w(),o=S(),c=x();function d(){const t=new URL(location.href);t.searchParams.delete("api-key"),o.replace(t.pathname+t.search)}function p(){const t=a.query["api-key"];if(typeof t=="string")return t}return L(async()=>{const t=p();if(!t){o.push({name:"error"});return}await c.createLogin(t).then(d),o.push({name:"workspace"})}),(t,C)=>(_(),k(y,null,{navbar:n(()=>[i($(B),{style:{padding:"5px 25px",border:"1px solid #f0f0f0"}},{title:n(()=>[i(f)]),_:1})]),content:n(()=>[r("div",j,[i(R)])]),_:1}))}});const J=u(z,[["__scopeId","data-v-944edebb"]]);export{J as default};
//# sourceMappingURL=ProjectLogin.6c094bd5.js.map
