import{_ as n}from"./TasksView.vue_vue_type_script_setup_true_lang.1a37e008.js";import{L as i}from"./tasksController.a7296231.js";import{d as p,o as d,c,w as e,b as o,aG as _,u as s,dd as m,a0 as l}from"./index.b466b20d.js";import{C as u}from"./ContentLayout.2ce25a75.js";import"./metadata.0f251151.js";import"./PhWebhooksLogo.vue.d1f03bcc.js";import"./ant-design.72d4f11b.js";import"./string.42378387.js";import"./dayjs.67389468.js";import"./index.a02e478f.js";import"./gateway.973a0055.js";import"./popupNotifcation.d1201e83.js";import"./scripts.67bab85e.js";import"./record.fd6fbc29.js";import"./linters.a9259de0.js";import"./asyncComputed.4467697c.js";import"./polling.f4d808f9.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[a]="12b1b918-a440-4620-90a4-aa1999d1605c",t._sentryDebugIdIdentifier="sentry-dbid-12b1b918-a440-4620-90a4-aa1999d1605c")}catch{}})();const f=p({__name:"Tasks",setup(t){const a=new i;return(r,y)=>(d(),c(u,null,{default:e(()=>[o(s(m),null,{default:e(()=>[_("Tasks")]),_:1}),o(n,{class:"tasks",api:s(a),stages:null,editor:""},null,8,["api"])]),_:1}))}});const G=l(f,[["__scopeId","data-v-10aa4cc9"]]);export{G as default};
//# sourceMappingURL=Tasks.9827de32.js.map
