.center[data-v-c67a9853]{display:flex;align-items:center}[data-v-c67a9853] .ant-tree-treenode{padding:0}[data-v-c67a9853] .ant-tree-switcher{width:12px}.tasks-manager[data-v-1fd9b528]{overflow:auto}.v-leave-to[data-v-1fd9b528],.v-enter-from[data-v-1fd9b528]{transition:all .4s;opacity:0;position:absolute;width:100%;transform:scale(.5)}.v-enter-to[data-v-1fd9b528],.v-leave-from[data-v-1fd9b528]{transition:all .4s;opacity:1;transform:scale(1)}
