import{d as c,o as s,c as l,w as o,b as n,$ as r,S as d,u as a,dh as i,er as p,e8 as f,bT as u,es as b,aW as g}from"./index.b466b20d.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="879428de-747c-477b-98c6-779cc6341b12",t._sentryDebugIdIdentifier="sentry-dbid-879428de-747c-477b-98c6-779cc6341b12")}catch{}})();const k=c({__name:"AbstraButton",props:{disabledTooltip:{},prefixCls:{},type:{},htmlType:{},shape:{},size:{},loading:{type:[Boolean,Object]},disabled:{type:Boolean},ghost:{type:Boolean},block:{type:Boolean},danger:{type:Boolean},icon:{},href:{},target:{},title:{},onClick:{type:[Function,Array]},onMousedown:{type:[Function,Array]}},setup(t){return(e,y)=>!e.disabledTooltip||!e.disabled?(s(),l(a(u),p(f({key:0},e.$props)),{default:o(()=>[n(a(i),{style:{display:"flex","align-items":"center","justify-content":"center",gap:"5px"}},{default:o(()=>[e.loading?d("",!0):r(e.$slots,"default",{key:0})]),_:3})]),_:3},16)):(s(),l(a(g),{key:1,title:e.disabledTooltip},{default:o(()=>[n(a(u),p(b(e.$props)),{default:o(()=>[n(a(i),{style:{display:"flex","align-items":"center","justify-content":"center",gap:"5px"}},{default:o(()=>[e.loading?d("",!0):r(e.$slots,"default",{key:0})]),_:3})]),_:3},16)]),_:3},8,["title"]))}});export{k as _};
//# sourceMappingURL=AbstraButton.vue_vue_type_script_setup_true_lang.b859cce0.js.map
