import{d as l,eh as c,f as r,o,Y as t,S as d,e9 as _,a0 as p}from"./index.b466b20d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="9ece0b21-4631-43ed-a18a-d06ac9edf9e5",e._sentryDebugIdIdentifier="sentry-dbid-9ece0b21-4631-43ed-a18a-d06ac9edf9e5")}catch{}})();const u={class:"logo"},g=["src","alt"],f={key:1},m=l({__name:"Logo",props:{imageUrl:{},brandName:{},hideText:{type:Boolean},size:{}},setup(e){const a=e;c(s=>({"9303a762":n.value}));const n=r(()=>a.size==="small"?"24px":a.size==="large"?"80px":"50px"),i=r(()=>`${a.brandName} Logo`);return(s,y)=>(o(),t("div",u,[s.imageUrl?(o(),t("img",{key:0,class:"logo-img",src:s.imageUrl,alt:i.value},null,8,g)):d("",!0),s.hideText?d("",!0):(o(),t("span",f,_(s.brandName),1))]))}});const h=p(m,[["__scopeId","data-v-f2a3ae27"]]);export{h as L};
//# sourceMappingURL=Logo.19805c7a.js.map
