import{k as i,T as n,m as r,P as o,C as d,M as p,s as c,n as s,p as f,q as b,t as m,v as u}from"./index.b466b20d.js";import{s as g,c as y,a}from"./workspaceStore.dd86fabd.js";import{_ as l}from"./App.vue_vue_type_style_index_0_lang.fbfa4c6b.js";import"./url.0fe255f2.js";import"./colorHelpers.26ff5df3.js";import"./PlayerConfigProvider.4015a478.js";import"./index.849469be.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="e78491ca-58bf-4b5d-b1a0-2e070fb2aa4b",t._sentryDebugIdIdentifier="sentry-dbid-e78491ca-58bf-4b5d-b1a0-2e070fb2aa4b")}catch{}})();class w{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await g();const t=y(),e=i({render:()=>f(l)});n.init(),r(e,a),w.init(),e.use(a),e.use(t),e.use(o),e.mount("#app"),e.component("VSelect",d),e.component("Markdown",p),e.component("Message",c),s(e,b),s(e,m),s(e,u)})();
//# sourceMappingURL=player.0cd5f087.js.map
