import{O as d}from"./workspaceStore.dd86fabd.js";import{d as c,X as l,o as i,Y as u,b as a,w as o,u as n,aG as s,dd as f,dc as b}from"./index.b466b20d.js";import"./url.0fe255f2.js";import"./colorHelpers.26ff5df3.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="9e4ec616-c52c-4b41-a990-9b643c77ef7b",e._sentryDebugIdIdentifier="sentry-dbid-9e4ec616-c52c-4b41-a990-9b643c77ef7b")}catch{}})();const w=c({__name:"OidcLogoutCallback",setup(e){return l(async()=>{await new d().logoutCallback()}),(t,r)=>(i(),u("div",null,[a(n(f),null,{default:o(()=>[s("You're authenticated")]),_:1}),a(n(b),null,{default:o(()=>[s(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{w as default};
//# sourceMappingURL=OidcLogoutCallback.37988b08.js.map
