.project-list-item[data-v-7ac918e2]{padding:10px;cursor:pointer;display:flex;align-items:center;justify-content:flex-start;gap:10px}.project-list-item[data-v-7ac918e2]:hover{background-color:#f5f5f5}
