import{U as s,dA as i,dB as d}from"./index.b466b20d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="85e51b95-bb9c-443b-a8bc-a0aed2c5f185",e._sentryDebugIdIdentifier="sentry-dbid-85e51b95-bb9c-443b-a8bc-a0aed2c5f185")}catch{}})();const{DatePicker:n,WeekPicker:t,MonthPicker:r,YearPicker:b,TimePicker:f,QuarterPicker:a,RangePicker:c}=i(d),u=s(n,{WeekPicker:t,MonthPicker:r,YearPicker:b,RangePicker:c,TimePicker:f,QuarterPicker:a,install:e=>(e.component(n.name,n),e.component(c.name,c),e.component(r.name,r),e.component(t.name,t),e.component(a.name,a),e)});export{u as D,r as M,a as Q,c as R,t as W};
//# sourceMappingURL=dayjs.67389468.js.map
