.container[data-v-b8d1fb7f]{display:flex;flex-direction:column;height:100vh}.content[data-v-b8d1fb7f]{display:flex;align-items:center;justify-content:center;margin:auto 0;box-sizing:border-box}.card[data-v-b8d1fb7f]{background-color:#fff;padding:30px;border-radius:8px;border:1px solid #f5f5f5;width:600px}
